@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2016-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of Django-Mailman.
 #
@@ -21,11 +21,13 @@
 This file is the main URL config for a Django website including Django-Mailman.
 """
 
-from django.conf.urls import include, url
+
+from django.conf.urls import include
+from django.urls import re_path
 
 
 urlpatterns = [
-    url(r'', include('django_mailman3.urls')),
-    url(r'^accounts/', include('allauth.urls')),
-    url(r'', include('django.contrib.auth.urls')),
+    re_path(r'', include('django_mailman3.urls')),
+    re_path(r'^accounts/', include('allauth.urls')),
+    re_path(r'', include('django.contrib.auth.urls')),
 ]
